<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use App\Rules\MatchPassword;
use Illuminate\Support\Facades\Hash;

class HomeController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('home');
    }

    public function changePassword()
    {
        return view('auth.change-password');
    }

    public function storeChangePassword(Request $request)
    {
        $request->validate([
            'current_password' => ['required', new MatchPassword],
            'new_password' => ['required'],
            'new_confirm_password' => ['same:new_password']
        ]);

        $update = User::find(auth()->user()->id)->update([
            'password' => Hash::make($request->new_password)
        ]);

        if ($update) {
            return redirect(route('home'));
        }
        abort(403);
    }

    public function adminAccounts()
    {
        $users = User::where('id', '!=', auth()->user()->getAuthIdentifier())->get();
        return view('auth.accounts', compact('users'));
    }

    public function deleteAdminAccount($id)
    {
        $user = User::findOrFail($id);

        if ($user->delete()) {
            return redirect(route('adminAccounts'));
        }
        abort(403);
    }

    public function createAdmin()
    {
        return view('auth.create-an-admin');
    }

    public function postCreateAdmin(Request $request)
    {
        $validated = $request->validate([
            'name' => 'required',
            'email' => 'required|email:rfc,dns|unique:users',
            'password' => 'required',
            'password_confirm' => 'same:password'
        ]);

        $create = User::create([
            'name' => $validated['name'],
            'email' => $validated['email'],
            'password' => Hash::make($validated['password']),
        ]);

        if ($create) {
            return redirect(route('adminAccounts'));
        }
        abort(403);
    }
}
